# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`storm::backend`](#stormbackend): StoRM Backend puppet module
* [`storm::backend::config`](#stormbackendconfig): StoRM Backend config class
* [`storm::backend::configdb`](#stormbackendconfigdb): StoRM Backend DB config class
* [`storm::backend::install`](#stormbackendinstall): StoRM Backend install class
* [`storm::backend::service`](#stormbackendservice): StoRM Backend service class
* [`storm::db`](#stormdb): Install MariaDB server and client, create empty databases 'storm_db' and 'storm_be_ISAM',
add storm user and all the necessary grants.
* [`storm::frontend`](#stormfrontend): StoRM Frontend puppet module
* [`storm::frontend::config`](#stormfrontendconfig): StoRM Frontend config class
* [`storm::frontend::install`](#stormfrontendinstall): StoRM Frontend install class
* [`storm::frontend::service`](#stormfrontendservice): StoRM Frontend service class
* [`storm::gridftp`](#stormgridftp): StoRM GridFTP puppet module
* [`storm::gridftp::config`](#stormgridftpconfig): StoRM GridFTP config class
* [`storm::gridftp::install`](#stormgridftpinstall): StoRM GridFTP install class
* [`storm::gridftp::service`](#stormgridftpservice): StoRM GridFTP service class
* [`storm::repo`](#stormrepo): Choose which StoRM repository you want to intall and enable. Also a custom list of repository URL can be specified.
* [`storm::users`](#stormusers): StoRM accounts configuration
* [`storm::webdav`](#stormwebdav): StoRM WebDAV puppet module
* [`storm::webdav::config`](#stormwebdavconfig): StoRM WebDAV config class
* [`storm::webdav::install`](#stormwebdavinstall): StoRM WebDAV install class
* [`storm::webdav::service`](#stormwebdavservice): StoRM WebDAV service class

### Defined types

* [`storm::backend::service_conf_file`](#stormbackendservice_conf_file): Starting from Puppet module v2.0.0, site administrators can inject
one or more .conf files into `/etc/systemd/system/storm-backend-server.service.d`
directory.
* [`storm::backend::storage_site_report`](#stormbackendstorage_site_report): Starting from Puppet module v2.0.0, the management of Storage Site Report has been improved.
Site administrators can add script and cron described in the [how-to](http://italiangrid.github.io/storm/documentation/how-to/how-to-publish-json-report/)
* [`storm::rootdir`](#stormrootdir): StoRM main storage area root directory defined resource
* [`storm::sarootdir`](#stormsarootdir): StoRM Storage Area root directory defined resource
* [`storm::webdav::application_file`](#stormwebdavapplication_file): Starting from Puppet module v2.0.0, the management of application.yml
file has been removed from storm::webdav class. Site administrators can edit
their own configuration files or use this defined type to inject one or more YAML
files into the proper directory.
* [`storm::webdav::drop_in_file`](#stormwebdavdrop_in_file): Use this define to inject one or more .conf files
into `/etc/systemd/system/storm-webdav.service.d` directory.
* [`storm::webdav::storage_area_file`](#stormwebdavstorage_area_file): Storage Areas can be configured singularly by using this defined type.
This strategy allows site administrators to keep their manifests unaware of
the improvements on StoRM WebDAV code. For example, if a new property is added
into Storage Area configuration files, you haven't to update your Puppet module
and all the service configuration will continue working.

### Data types

* [`Storm::Backend::Acl`](#stormbackendacl): The ACL type for storm-backend-server
* [`Storm::Backend::AclMode`](#stormbackendaclmode): The AclMode type for storm-backend-server
* [`Storm::Backend::BalanceStrategy`](#stormbackendbalancestrategy): The BalanceStrategy type for storm-backend-server
* [`Storm::Backend::Endpoint`](#stormbackendendpoint): The Endpoint type for storm-backend-server
* [`Storm::Backend::FileSystem`](#stormbackendfilesystem): The FileSystem type for storm-backend-server
* [`Storm::Backend::FsDriver`](#stormbackendfsdriver): The FsDriver type for storm-backend-server
* [`Storm::Backend::FsType`](#stormbackendfstype): The FsType type for storm-backend-server
* [`Storm::Backend::Gsiftp`](#stormbackendgsiftp): The Gsiftp type for storm-backend-server
* [`Storm::Backend::GsiftpPoolMember`](#stormbackendgsiftppoolmember): The GsiftpPoolMember type for storm-backend-server
* [`Storm::Backend::Pool`](#stormbackendpool): The Pool type for storm-backend-server
* [`Storm::Backend::Quota`](#stormbackendquota): The Quota type for storm-backend-server
* [`Storm::Backend::Rfio`](#stormbackendrfio): The Rfio type for storm-backend-server
* [`Storm::Backend::SrmPoolMember`](#stormbackendsrmpoolmember): The SrmPoolMember type for storm-backend-server
* [`Storm::Backend::StorageArea`](#stormbackendstoragearea): The storage area type for storm-backend-server
* [`Storm::Backend::StorageClass`](#stormbackendstorageclass): The StorageClass type for storm-backend-server
* [`Storm::Backend::TransferProtocol`](#stormbackendtransferprotocol): The TransferProtocol type for storm-backend-server
* [`Storm::Backend::Webdav`](#stormbackendwebdav): The WebDAV type for storm-backend-server
* [`Storm::Backend::WebdavPoolMember`](#stormbackendwebdavpoolmember): The WebdavPoolMember type for storm-backend-server
* [`Storm::Backend::Xroot`](#stormbackendxroot): The Xroot type for storm-backend-server
* [`Storm::CustomRepo`](#stormcustomrepo): The storage area type for storm-webdav
* [`Storm::Webdav::StorageArea`](#stormwebdavstoragearea): The storage area type for storm-webdav.

## Classes

### <a name="stormbackend"></a>`storm::backend`

StoRM Backend puppet module

#### Examples

##### Example of usage

```puppet
class { 'storm::backend':
  hostname => 'backend.test.example',
  db_username => 'storm',
  db_password => 'bluemoon',
  srm_pool_members => [
    {
      'hostname' => 'frontend.test.example',
    }
  ],
  gsiftp_pool_members => [
    {
      'hostname' => 'gridftp.test.example',
    },
  ],
  webdav_pool_members => [
    {
      'hostname' => 'webdav.test.example',
    },
  ],
  storage_areas => [
    {
      'name'               => 'test.vo',
      'root_path'          => '/storage/test.vo',
      'access_points'      => ['/test.vo'],
      'vos'                => ['test.vo'],
      'storage_class'      => 'T0D1',
      'online_size'        => 4,
      'transfer_protocols' => ['file', 'gsiftp', 'https'],
    },
  ],
}
```

#### Parameters

The following parameters are available in the `storm::backend` class:

* [`hostname`](#hostname)
* [`db_hostname`](#db_hostname)
* [`db_username`](#db_username)
* [`db_password`](#db_password)
* [`xroot_hostname`](#xroot_hostname)
* [`xroot_port`](#xroot_port)
* [`gsiftp_pool_balance_strategy`](#gsiftp_pool_balance_strategy)
* [`gsiftp_pool_members`](#gsiftp_pool_members)
* [`webdav_pool_balance_strategy`](#webdav_pool_balance_strategy)
* [`webdav_pool_members`](#webdav_pool_members)
* [`srm_pool_members`](#srm_pool_members)
* [`transfer_protocols`](#transfer_protocols)
* [`fs_type`](#fs_type)
* [`storage_areas`](#storage_areas)
* [`frontend_public_host`](#frontend_public_host)
* [`frontend_port`](#frontend_port)
* [`directory_automatic_creation`](#directory_automatic_creation)
* [`directory_writeperm`](#directory_writeperm)
* [`rest_services_port`](#rest_services_port)
* [`rest_services_max_threads`](#rest_services_max_threads)
* [`rest_services_max_queue_size`](#rest_services_max_queue_size)
* [`xmlrpc_unsecure_server_port`](#xmlrpc_unsecure_server_port)
* [`xmlrpc_maxthread`](#xmlrpc_maxthread)
* [`xmlrpc_max_queue_size`](#xmlrpc_max_queue_size)
* [`xmlrpc_security_enabled`](#xmlrpc_security_enabled)
* [`xmlrpc_security_token`](#xmlrpc_security_token)
* [`ptg_skip_acl_setup`](#ptg_skip_acl_setup)
* [`pinlifetime_default`](#pinlifetime_default)
* [`pinlifetime_maximum`](#pinlifetime_maximum)
* [`sanity_check_enabled`](#sanity_check_enabled)
* [`service_du_enabled`](#service_du_enabled)
* [`service_du_delay`](#service_du_delay)
* [`service_du_interval`](#service_du_interval)
* [`max_ls_entries`](#max_ls_entries)
* [`gc_pinnedfiles_cleaning_delay`](#gc_pinnedfiles_cleaning_delay)
* [`gc_pinnedfiles_cleaning_interval`](#gc_pinnedfiles_cleaning_interval)
* [`gc_purge_enabled`](#gc_purge_enabled)
* [`gc_purge_interval`](#gc_purge_interval)
* [`gc_purge_size`](#gc_purge_size)
* [`gc_expired_request_time`](#gc_expired_request_time)
* [`gc_expired_inprogress_time`](#gc_expired_inprogress_time)
* [`gc_ptp_transit_interval`](#gc_ptp_transit_interval)
* [`gc_ptp_transit_start_delay`](#gc_ptp_transit_start_delay)
* [`extraslashes_file`](#extraslashes_file)
* [`extraslashes_root`](#extraslashes_root)
* [`extraslashes_gsiftp`](#extraslashes_gsiftp)
* [`db_connection_pool_enabled`](#db_connection_pool_enabled)
* [`db_connection_pool_max_active`](#db_connection_pool_max_active)
* [`db_connection_pool_max_wait`](#db_connection_pool_max_wait)
* [`asynch_db_reconnect_period`](#asynch_db_reconnect_period)
* [`asynch_db_delay_period`](#asynch_db_delay_period)
* [`asynch_picking_initial_delay`](#asynch_picking_initial_delay)
* [`asynch_picking_time_interval`](#asynch_picking_time_interval)
* [`asynch_picking_max_batch_size`](#asynch_picking_max_batch_size)
* [`requests_scheduler_core_size`](#requests_scheduler_core_size)
* [`requests_scheduler_max_size`](#requests_scheduler_max_size)
* [`requests_scheduler_queue_size`](#requests_scheduler_queue_size)
* [`ptp_requests_scheduler_core_size`](#ptp_requests_scheduler_core_size)
* [`ptp_requests_scheduler_max_size`](#ptp_requests_scheduler_max_size)
* [`ptp_requests_scheduler_queue_size`](#ptp_requests_scheduler_queue_size)
* [`ptg_requests_scheduler_core_size`](#ptg_requests_scheduler_core_size)
* [`ptg_requests_scheduler_max_size`](#ptg_requests_scheduler_max_size)
* [`ptg_requests_scheduler_queue_size`](#ptg_requests_scheduler_queue_size)
* [`bol_requests_scheduler_core_size`](#bol_requests_scheduler_core_size)
* [`bol_requests_scheduler_max_size`](#bol_requests_scheduler_max_size)
* [`bol_requests_scheduler_queue_size`](#bol_requests_scheduler_queue_size)
* [`info_config_file`](#info_config_file)
* [`info_sitename`](#info_sitename)
* [`info_storage_default_root`](#info_storage_default_root)
* [`info_endpoint_quality_level`](#info_endpoint_quality_level)
* [`info_webdav_pool_list`](#info_webdav_pool_list)
* [`info_frontend_host_list`](#info_frontend_host_list)
* [`jvm_options`](#jvm_options)
* [`jmx`](#jmx)
* [`jmx_options`](#jmx_options)
* [`lcmaps_db_file`](#lcmaps_db_file)
* [`lcmaps_policy_name`](#lcmaps_policy_name)
* [`lcmaps_log_file`](#lcmaps_log_file)
* [`lcmaps_debug_level`](#lcmaps_debug_level)
* [`http_turl_prefix`](#http_turl_prefix)
* [`storm_limit_nofile`](#storm_limit_nofile)
* [`manage_path_authz_db`](#manage_path_authz_db)
* [`path_authz_db_file`](#path_authz_db_file)
* [`manage_storm_properties`](#manage_storm_properties)
* [`path_storm_properties`](#path_storm_properties)

##### <a name="hostname"></a>`hostname`

Data type: `String`

StoRM Backend Fully Qualified Domain Name

Default value: `$fqdn`

##### <a name="db_hostname"></a>`db_hostname`

Data type: `String`

Fully Qualified Domain Name of database hostname. Default value: `hostname`.

Default value: `$hostname`

##### <a name="db_username"></a>`db_username`

Data type: `String`

The name of user used to connect to local database. Default: storm

##### <a name="db_password"></a>`db_password`

Data type: `String`

Password for the user in `db_storm_username`. Default: bluemoon

##### <a name="xroot_hostname"></a>`xroot_hostname`

Data type: `String`

Root server (default value for all Storage Areas).
Note: you may change the settings for each SA acting on its configuration.

Default value: `$hostname`

##### <a name="xroot_port"></a>`xroot_port`

Data type: `Integer`

Root server port (default value for all Storage Areas).

##### <a name="gsiftp_pool_balance_strategy"></a>`gsiftp_pool_balance_strategy`

Data type: `Storm::Backend::BalanceStrategy`

Load balancing strategy for GridFTP server pool (default value for all Storage Areas).
Note: you may change the settings for each SA acting on its configuration.
Available values: round-robin, smart-rr, random, weight. Default value: round-robin.
See [Storm::Backend::BalanceStrategy](#stormbackendbalancestrategy).

##### <a name="gsiftp_pool_members"></a>`gsiftp_pool_members`

Data type: `Array[Storm::Backend::GsiftpPoolMember]`

Array of [Storm::Backend::GsiftpPoolMember](#stormbackendgsiftppoolmember).
GridFTP servers pool list (default value for all Storage Areas).
Note: you may change the settings for each SA acting on its configuration.

##### <a name="webdav_pool_balance_strategy"></a>`webdav_pool_balance_strategy`

Data type: `Storm::Backend::BalanceStrategy`

Load balancing strategy for WebDAV server pools (default value for all Storage Areas).
Note: you may change the settings for each SA acting on its configuration.
Available values: round-robin, smart-rr, random, weight. Default value: round-robin.
See [Storm::Backend::BalanceStrategy](#stormbackendbalancestrategy).

##### <a name="webdav_pool_members"></a>`webdav_pool_members`

Data type: `Array[Storm::Backend::WebdavPoolMember]`

Array of [Storm::Backend::WebdavPoolMember](#stormbackendwebdavpoolmember).
WebDAV endpoints pool list (default value for all Storage Areas).
Note: you may change the settings for each SA acting on its configuration.

##### <a name="srm_pool_members"></a>`srm_pool_members`

Data type: `Array[Storm::Backend::SrmPoolMember]`

Array of [Storm::Backend::SrmPoolMember](#stormbackendsrmpoolmember).
Frontend endpoints pool list (default value for all Storage Areas).
Note: you may change the settings for each SA acting on its configuration.

##### <a name="transfer_protocols"></a>`transfer_protocols`

Data type: `Array[Storm::Backend::TransferProtocol]`

List of supported (and published) transfer protocols (default value for all Storage Areas).
Note: you may change the settings for each SA acting on its configuration.

##### <a name="fs_type"></a>`fs_type`

Data type: `Storm::Backend::FsType`

File System Type (default value for all Storage Areas).
Note: you may change the settings for each SA acting on its configuration.
Available values: posixfs, gpfs and test. Default value: posixfs
See [Storm::Backend::FsType](#stormbackendfstype).

##### <a name="storage_areas"></a>`storage_areas`

Data type: `Array[Storm::Backend::StorageArea]`

List of supported Storage Areas.
Array of [Storm::Backend::StorageArea](#stormbackendstoragearea).

##### <a name="frontend_public_host"></a>`frontend_public_host`

Data type: `String`

StoRM Frontend service public host. It’s used by StoRM Info Provider to publish the SRM endpoint into the Resource BDII.
Default value: `hostname`

Default value: `$hostname`

##### <a name="frontend_port"></a>`frontend_port`

Data type: `Integer`

StoRM Frontend service port. Default value: 8444

##### <a name="directory_automatic_creation"></a>`directory_automatic_creation`

Data type: `Boolean`

Flag to enable automatic missing directory creation upon srmPrepareToPut requests. Default: false.

##### <a name="directory_writeperm"></a>`directory_writeperm`

Data type: `Boolean`

Flag to enable directory write permission setting upon srmMkDir requests on created directories. Default: false.

##### <a name="rest_services_port"></a>`rest_services_port`

Data type: `Integer`

REST services port. Default value: 9998

##### <a name="rest_services_max_threads"></a>`rest_services_max_threads`

Data type: `Integer`

REST services max active requests. Default: 100

##### <a name="rest_services_max_queue_size"></a>`rest_services_max_queue_size`

Data type: `Integer`

REST services max queue size of accepted requests. Default: 1000

##### <a name="xmlrpc_unsecure_server_port"></a>`xmlrpc_unsecure_server_port`

Data type: `Integer`

Port to listen on for incoming XML-RPC connections from Frontends(s). Default: 8080

##### <a name="xmlrpc_maxthread"></a>`xmlrpc_maxthread`

Data type: `Integer`

Number of threads managing XML-RPC connection from Frontends(s).
A well sized value for this parameter have to be at least equal to the sum of the number of working threads in all Frontends.
Default: 100.

##### <a name="xmlrpc_max_queue_size"></a>`xmlrpc_max_queue_size`

Data type: `Integer`

Max number of accepted and queued XML-RPC connection from Frontends(s). Default: **1000**

##### <a name="xmlrpc_security_enabled"></a>`xmlrpc_security_enabled`

Data type: `Boolean`

Whether the backend will require a token to be present for accepting XML-RPC requests. Default: true.

##### <a name="xmlrpc_security_token"></a>`xmlrpc_security_token`

Data type: `String`

The token that the backend will require to be present for accepting XML-RPC requests.
Mandatory if xmlrpc_security_enabled is true.

##### <a name="ptg_skip_acl_setup"></a>`ptg_skip_acl_setup`

Data type: `Boolean`

Skip ACL setup for PtG requests. Default: false.

##### <a name="pinlifetime_default"></a>`pinlifetime_default`

Data type: `Integer`

Default PinLifetime in seconds used for pinning files in case of srmPrepareToPut or srmPrepareToGet operation
without any pinLifetime specified. Default: 259200.

##### <a name="pinlifetime_maximum"></a>`pinlifetime_maximum`

Data type: `Integer`

Maximum PinLifetime allowed in seconds. Default: 1814400.

##### <a name="sanity_check_enabled"></a>`sanity_check_enabled`

Data type: `Boolean`

Enable/disable sanity checks during bootstrap phase. Default: true.

##### <a name="service_du_enabled"></a>`service_du_enabled`

Data type: `Boolean`

Flag to enable disk usage service. Default: false.

##### <a name="service_du_delay"></a>`service_du_delay`

Data type: `Integer`

The initial delay before the service is started (seconds). Default: 60.

##### <a name="service_du_interval"></a>`service_du_interval`

Data type: `Integer`

The interval in seconds between successive run. Default: 360.

##### <a name="max_ls_entries"></a>`max_ls_entries`

Data type: `Integer`

Maximum number of entries returned by an srmLs call.
Since in case of recursive srmLs results can be in order of million, this prevent a server overload. Default: 500.

##### <a name="gc_pinnedfiles_cleaning_delay"></a>`gc_pinnedfiles_cleaning_delay`

Data type: `Integer`

Initial delay before starting the reserved space, JIT ACLs and pinned files garbage collection process, in seconds. Default: 10.

##### <a name="gc_pinnedfiles_cleaning_interval"></a>`gc_pinnedfiles_cleaning_interval`

Data type: `Integer`

Time interval in seconds between successive purging run. Default: 300.

##### <a name="gc_purge_enabled"></a>`gc_purge_enabled`

Data type: `Boolean`

Enable the request garbage collector. Default: true.

##### <a name="gc_purge_interval"></a>`gc_purge_interval`

Data type: `Integer`

Time interval in seconds between successive purging run. Default: 600.

##### <a name="gc_purge_size"></a>`gc_purge_size`

Data type: `Integer`

Number of requests picked up for cleaning from the requests garbage collector at each run.
This value is use also by Tape Recall Garbage Collector. Default: 800

##### <a name="gc_expired_request_time"></a>`gc_expired_request_time`

Data type: `Integer`

Time in seconds to consider a request expired after its submission. Default: 604800 seconds (1 week).
From StoRM 1.11.13 it is used also to identify how much time is needed to consider a completed recall task as cleanable.

##### <a name="gc_expired_inprogress_time"></a>`gc_expired_inprogress_time`

Data type: `Integer`

Time in seconds to consider an in-progress ptp request as expired. Default: 2592000 seconds (1 month).

##### <a name="gc_ptp_transit_interval"></a>`gc_ptp_transit_interval`

Data type: `Integer`

Time interval in seconds between successive expired put requests agent run. Default: 3000.

##### <a name="gc_ptp_transit_start_delay"></a>`gc_ptp_transit_start_delay`

Data type: `Integer`

Initial delay before starting the expired put requests agent process, in seconds. Default: 60

##### <a name="extraslashes_file"></a>`extraslashes_file`

Data type: `String`

Add extra slashes after the “authority” part of a TURL for file protocol. Defaul: ''

##### <a name="extraslashes_root"></a>`extraslashes_root`

Data type: `String`

Add extra slashes after the “authority” part of a TURL for xroot protocol. Default: '/'

##### <a name="extraslashes_gsiftp"></a>`extraslashes_gsiftp`

Data type: `String`

Add extra slashes after the “authority” part of a TURL for gsiftp protocol. Default: '/'

##### <a name="db_connection_pool_enabled"></a>`db_connection_pool_enabled`

Data type: `Boolean`

Enable the database connection pool. Default: true

##### <a name="db_connection_pool_max_active"></a>`db_connection_pool_max_active`

Data type: `Integer`

Database connection pool max active connections. Default: 10

##### <a name="db_connection_pool_max_wait"></a>`db_connection_pool_max_wait`

Data type: `Integer`

Database connection pool max wait time to provide a connection. Default: 50

##### <a name="asynch_db_reconnect_period"></a>`asynch_db_reconnect_period`

Data type: `Integer`

Database connection refresh time intervall in seconds. Default: 18000

##### <a name="asynch_db_delay_period"></a>`asynch_db_delay_period`

Data type: `Integer`

Database connection refresh initial delay in seconds. Default: 30.

##### <a name="asynch_picking_initial_delay"></a>`asynch_picking_initial_delay`

Data type: `Integer`

Initial delay before starting to pick requests from the DB, in seconds. Default: 1.

##### <a name="asynch_picking_time_interval"></a>`asynch_picking_time_interval`

Data type: `Integer`

Polling interval in seconds to pick up new SRM requests. Default: 2.

##### <a name="asynch_picking_max_batch_size"></a>`asynch_picking_max_batch_size`

Data type: `Integer`

Maximum number of requests picked up at each polling time. Default: 100.

##### <a name="requests_scheduler_core_size"></a>`requests_scheduler_core_size`

Data type: `Integer`

Crusher Scheduler worker pool base size. Default: 50.

##### <a name="requests_scheduler_max_size"></a>`requests_scheduler_max_size`

Data type: `Integer`

Crusher Schedule worker pool max size. Default: 200.

##### <a name="requests_scheduler_queue_size"></a>`requests_scheduler_queue_size`

Data type: `Integer`

Request queue maximum size. Default: 2000.

##### <a name="ptp_requests_scheduler_core_size"></a>`ptp_requests_scheduler_core_size`

Data type: `Integer`

PrepareToPut worker pool base size. Default: 50.

##### <a name="ptp_requests_scheduler_max_size"></a>`ptp_requests_scheduler_max_size`

Data type: `Integer`

PrepareToPut worker pool max size. Default: 200.

##### <a name="ptp_requests_scheduler_queue_size"></a>`ptp_requests_scheduler_queue_size`

Data type: `Integer`

PrepareToPut request queue maximum size. Default: 1000.

##### <a name="ptg_requests_scheduler_core_size"></a>`ptg_requests_scheduler_core_size`

Data type: `Integer`

PrepareToGet worker pool base size. Default: 50.

##### <a name="ptg_requests_scheduler_max_size"></a>`ptg_requests_scheduler_max_size`

Data type: `Integer`

PrepareToGet worker pool max size. Default: 200.

##### <a name="ptg_requests_scheduler_queue_size"></a>`ptg_requests_scheduler_queue_size`

Data type: `Integer`

PrepareToGet request queue maximum size. Default: 2000.

##### <a name="bol_requests_scheduler_core_size"></a>`bol_requests_scheduler_core_size`

Data type: `Integer`

BringOnline worker pool base size. Default: 50.

##### <a name="bol_requests_scheduler_max_size"></a>`bol_requests_scheduler_max_size`

Data type: `Integer`

BringOnline Worker pool max size. Default: 200.

##### <a name="bol_requests_scheduler_queue_size"></a>`bol_requests_scheduler_queue_size`

Data type: `Integer`

BringOnline request queue maximum size. Default: 2000.

##### <a name="info_config_file"></a>`info_config_file`

Data type: `String`

The key-value file used by StoRM Info Provider as its configuration file.

##### <a name="info_sitename"></a>`info_sitename`

Data type: `String`

It’s the human-readable name of your site used to set the Glue-SiteName attribute.

##### <a name="info_storage_default_root"></a>`info_storage_default_root`

Data type: `String`

Default directory for Storage Areas.

##### <a name="info_endpoint_quality_level"></a>`info_endpoint_quality_level`

Data type: `Integer`

Endpoint maturity level to be published by the StoRM info provider. Default value: 2.

##### <a name="info_webdav_pool_list"></a>`info_webdav_pool_list`

Data type: `Array[Storm::Backend::WebdavPoolMember]`

List of published webdav endpoints.

##### <a name="info_frontend_host_list"></a>`info_frontend_host_list`

Data type: `Array[Storm::Backend::SrmPoolMember]`

List of published srm endpoints.

##### <a name="jvm_options"></a>`jvm_options`

Data type: `String`



##### <a name="jmx"></a>`jmx`

Data type: `Boolean`



##### <a name="jmx_options"></a>`jmx_options`

Data type: `String`



##### <a name="lcmaps_db_file"></a>`lcmaps_db_file`

Data type: `String`



##### <a name="lcmaps_policy_name"></a>`lcmaps_policy_name`

Data type: `String`



##### <a name="lcmaps_log_file"></a>`lcmaps_log_file`

Data type: `String`



##### <a name="lcmaps_debug_level"></a>`lcmaps_debug_level`

Data type: `Integer`



##### <a name="http_turl_prefix"></a>`http_turl_prefix`

Data type: `String`



##### <a name="storm_limit_nofile"></a>`storm_limit_nofile`

Data type: `Integer`

Sets LimitNOFILE value.

##### <a name="manage_path_authz_db"></a>`manage_path_authz_db`

Data type: `Boolean`

If true, allows to set content of path-authz.db file.

##### <a name="path_authz_db_file"></a>`path_authz_db_file`

Data type: `String`

If manage_path_authz_db is true, set the content from this source path

##### <a name="manage_storm_properties"></a>`manage_storm_properties`

Data type: `Boolean`

If true, allows to set content of storm.properties file wuth the file pointed by path_storm_properties.

##### <a name="path_storm_properties"></a>`path_storm_properties`

Data type: `String`

If manage_storm_properties is true, set the content of storm.properties from this source path

### <a name="stormbackendconfig"></a>`storm::backend::config`

StoRM Backend config class

### <a name="stormbackendconfigdb"></a>`storm::backend::configdb`

StoRM Backend DB config class

### <a name="stormbackendinstall"></a>`storm::backend::install`

StoRM Backend install class

### <a name="stormbackendservice"></a>`storm::backend::service`

StoRM Backend service class

### <a name="stormdb"></a>`storm::db`

Install MariaDB server and client, create empty databases 'storm_db' and 'storm_be_ISAM',
add storm user and all the necessary grants.

#### Examples

##### Basic usage:

```puppet
include storm::db
```

#### Parameters

The following parameters are available in the `storm::db` class:

* [`fqdn_hostname`](#fqdn_hostname)
* [`root_password`](#root_password)
* [`storm_username`](#storm_username)
* [`storm_password`](#storm_password)
* [`override_options`](#override_options)
* [`limit_no_file`](#limit_no_file)

##### <a name="fqdn_hostname"></a>`fqdn_hostname`

Data type: `String`

The Fully Qualified Domain Name of the host. Default value got from Puppet fact `fqdn`.

Default value: `$fqdn`

##### <a name="root_password"></a>`root_password`

Data type: `String`

MySQL root password. Default: 'storm'.

##### <a name="storm_username"></a>`storm_username`

Data type: `String`

The username of the user used by storm services to query the databases. Default 'storm'.

##### <a name="storm_password"></a>`storm_password`

Data type: `String`

The password of 'storm' username used by storm services to access the databases. Default: 'storm'.

##### <a name="override_options"></a>`override_options`

Data type: `Data`

MySQL server override options. Read more about this at https://forge.puppet.com/puppetlabs/mysql/reference#override_options.

##### <a name="limit_no_file"></a>`limit_no_file`

Data type: `Integer`

MariaDB setting for limitNoFile

### <a name="stormfrontend"></a>`storm::frontend`

StoRM Frontend puppet module

#### Examples

##### Example of usage

```puppet
class { 'storm::frontend':
  be_xmlrpc_host  => 'storm-backend.host.org',
  be_xmlrpc_token => 'my-secret-xmlrpc-token',
  db_host         => 'storm-backend.host.org',
  db_passwd       => 'my-secret-db-password',
}
```

#### Parameters

The following parameters are available in the `storm::frontend` class:

* [`storm_frontend_server_conf_file`](#storm_frontend_server_conf_file)
* [`be_xmlrpc_host`](#be_xmlrpc_host)
* [`be_xmlrpc_port`](#be_xmlrpc_port)
* [`be_xmlrpc_token`](#be_xmlrpc_token)
* [`be_xmlrpc_path`](#be_xmlrpc_path)
* [`be_recalltable_port`](#be_recalltable_port)
* [`db_host`](#db_host)
* [`db_user`](#db_user)
* [`db_passwd`](#db_passwd)
* [`port`](#port)
* [`threadpool_maxpending`](#threadpool_maxpending)
* [`threadpool_threads_number`](#threadpool_threads_number)
* [`gsoap_maxpending`](#gsoap_maxpending)
* [`check_user_blacklisting`](#check_user_blacklisting)
* [`argus_pepd_endpoint`](#argus_pepd_endpoint)
* [`argus_resource_id`](#argus_resource_id)
* [`monitoring_enabled`](#monitoring_enabled)
* [`monitoring_time_interval`](#monitoring_time_interval)
* [`monitoring_detailed`](#monitoring_detailed)
* [`security_enable_vomscheck`](#security_enable_vomscheck)
* [`log_debuglevel`](#log_debuglevel)

##### <a name="storm_frontend_server_conf_file"></a>`storm_frontend_server_conf_file`

Data type: `String`

Use this parameter to provide your own storm-frontend-server.conf file.
This can be used, for example, when you're using the latest module version
to configure an old StoRM deployment. This parameter is used only when it has
a non-empty value and it overwrites several other module parameters.
Default value: empty string (that means not used).

##### <a name="be_xmlrpc_host"></a>`be_xmlrpc_host`

Data type: `String`

StoRM Backend hostname.

Default value: `$fqdn`

##### <a name="be_xmlrpc_port"></a>`be_xmlrpc_port`

Data type: `Integer`

StoRM Backend XML-RPC server port. Default value: 8080.

##### <a name="be_xmlrpc_token"></a>`be_xmlrpc_token`

Data type: `String`

Security token used for communicating with StoRM Backend. Mandatory.

##### <a name="be_xmlrpc_path"></a>`be_xmlrpc_path`

Data type: `String`

StoRM Backend XML-RPC server path. Default value: '/RPC2'.

##### <a name="be_recalltable_port"></a>`be_recalltable_port`

Data type: `Integer`

StoRM Backend REST server port running on the Backend machine. Default value: 9998.

##### <a name="db_host"></a>`db_host`

Data type: `String`

Host for database connection.

Default value: `$be_xmlrpc_host`

##### <a name="db_user"></a>`db_user`

Data type: `String`

User for database connection. Default value: 'storm'.

##### <a name="db_passwd"></a>`db_passwd`

Data type: `String`

Password for database connection. Default value: 'storm'.

##### <a name="port"></a>`port`

Data type: `Integer`

Frontend service port. Default value: 8444.

##### <a name="threadpool_maxpending"></a>`threadpool_maxpending`

Data type: `Integer`

Size of the internal queue used to maintain SRM tasks in case there are no free worker threads.
Default value: 200.

##### <a name="threadpool_threads_number"></a>`threadpool_threads_number`

Data type: `Integer`

Size of the worker thread pool. Default value: 50.

##### <a name="gsoap_maxpending"></a>`gsoap_maxpending`

Data type: `Integer`

Size of the GSOAP queue used to maintain pending SRM requests. Default value: 1000.

##### <a name="check_user_blacklisting"></a>`check_user_blacklisting`

Data type: `Boolean`

Enable/disable user blacklisting. Default value: false.

##### <a name="argus_pepd_endpoint"></a>`argus_pepd_endpoint`

Data type: `String`

The complete service endpoint of Argus PEP server. Mandatory if `check_user_blacklisting` is true.

##### <a name="argus_resource_id"></a>`argus_resource_id`

Data type: `String`

The resource id is used to target a resource (or set of resources, if wildcards are used) under the control of Argus authorization.
Mandatory if `check_user_blacklisting` is true.

##### <a name="monitoring_enabled"></a>`monitoring_enabled`

Data type: `Boolean`

Enable/disable monitoring. Default value: true.

##### <a name="monitoring_time_interval"></a>`monitoring_time_interval`

Data type: `Integer`

Time interval in seconds between each monitoring round. Default value: 60.

##### <a name="monitoring_detailed"></a>`monitoring_detailed`

Data type: `Boolean`

Enable/disable detailed monitoring. Default value: false.

##### <a name="security_enable_vomscheck"></a>`security_enable_vomscheck`

Data type: `Boolean`

Flag to enable/disable checking proxy VOMS credentials. Default value: true.

##### <a name="log_debuglevel"></a>`log_debuglevel`

Data type: `String`

Logging level. Possible values are: ERROR, WARN, INFO, DEBUG, DEBUG2. Default value: INFO.

### <a name="stormfrontendconfig"></a>`storm::frontend::config`

StoRM Frontend config class

### <a name="stormfrontendinstall"></a>`storm::frontend::install`

StoRM Frontend install class

### <a name="stormfrontendservice"></a>`storm::frontend::service`

StoRM Frontend service class

### <a name="stormgridftp"></a>`storm::gridftp`

Parameters
----------

The StoRM GridFTP configuration parameters are:

* `port`: the port used by GridFTP server service;
* `port_range`: the range of ports used by transfer sockets; format is 'MIN,MAX';
* `connections_max`: the number of max allowed connections to server;

#### Examples

##### Example of usage

```puppet
class { 'storm::gridftp':
  port            => 2811,
  port_range      => '20000,25000',
  connections_max => 2000,
}
```

#### Parameters

The following parameters are available in the `storm::gridftp` class:

* [`port`](#port)
* [`port_range`](#port_range)
* [`connections_max`](#connections_max)
* [`log_single`](#log_single)
* [`log_transfer`](#log_transfer)
* [`redirect_lcmaps_log`](#redirect_lcmaps_log)
* [`llgt_log_file`](#llgt_log_file)
* [`lcmaps_debug_level`](#lcmaps_debug_level)
* [`lcas_debug_level`](#lcas_debug_level)
* [`load_storm_dsi_module`](#load_storm_dsi_module)
* [`log_level`](#log_level)
* [`data_interface`](#data_interface)

##### <a name="port"></a>`port`

Data type: `Integer`

The port used by GridFTP server service.

##### <a name="port_range"></a>`port_range`

Data type: `String`

The range of ports used by transfer sockets; format is 'MIN,MAX'.

##### <a name="connections_max"></a>`connections_max`

Data type: `Integer`

The number of max allowed connections to server.

##### <a name="log_single"></a>`log_single`

Data type: `String`

Session log file path. Default is: /var/log/storm/storm-gridftp-session.log

##### <a name="log_transfer"></a>`log_transfer`

Data type: `String`

Transfer log file path. Default is: /var/log/storm/storm-globus-gridftp.log

##### <a name="redirect_lcmaps_log"></a>`redirect_lcmaps_log`

Data type: `Boolean`

If true, redirect the LCMAPS log to the file specified by 'llgt_log_file'.

##### <a name="llgt_log_file"></a>`llgt_log_file`

Data type: `String`

The LCMAPS log file used if 'redirect_lcmaps_log' is true.

##### <a name="lcmaps_debug_level"></a>`lcmaps_debug_level`

Data type: `Integer`

The LCMAPS logging level. Values from 0 (ERROR) to 5 (DEBUG). Default: 3 (INFO)

##### <a name="lcas_debug_level"></a>`lcas_debug_level`

Data type: `Integer`

The LCAS logging level. Values from 0 (ERROR) to 5 (DEBUG). Default: 3 (INFO)

##### <a name="load_storm_dsi_module"></a>`load_storm_dsi_module`

Data type: `Boolean`

Enable/Disable StoRM DSI module. Default: true (enabled)

##### <a name="log_level"></a>`log_level`

Data type: `String`



##### <a name="data_interface"></a>`data_interface`

Data type: `Optional[String]`

(Optional) Hostname or IP address of the interface to use for data connections.
Set this to your external IP address in case your public address is different from
your local address (e.g. the floating IP address of a Virtual Machine).

### <a name="stormgridftpconfig"></a>`storm::gridftp::config`

StoRM GridFTP config class

### <a name="stormgridftpinstall"></a>`storm::gridftp::install`

StoRM GridFTP install class

### <a name="stormgridftpservice"></a>`storm::gridftp::service`

StoRM GridFTP service class

### <a name="stormrepo"></a>`storm::repo`

Choose which StoRM repository you want to intall and enable. Also a custom list of repository URL can be specified.

#### Examples

##### Install all the repositories and enable only nightly repo as follow:

```puppet
class { 'storm::repo':
  enabled => ['stable'],
}
```

#### Parameters

The following parameters are available in the `storm::repo` class:

* [`installed`](#installed)
* [`enabled`](#enabled)
* [`extra`](#extra)

##### <a name="installed"></a>`installed`

Data type: `Array[Enum['stable', 'beta', 'nightly']]`

The list of repositories that have to be installed. Allowed values are `stable`, `beta` and `nightly`. Optional.

##### <a name="enabled"></a>`enabled`

Data type: `Array[Enum['stable', 'beta', 'nightly']]`

The list of repositories that have to be enabled. Allowed values are `stable`, `beta` and `nightly`. Optional.

##### <a name="extra"></a>`extra`

Data type: `Array[Storm::CustomRepo]`

A list of repository that have to be created. Optional.

### <a name="stormusers"></a>`storm::users`

Parameters
----------

StoRM needs a 'storm' Unix user, member of an 'edguser' group.
This class creates all the necessary users.

#### Examples

##### Example of usage

```puppet
class { 'storm::users':
  groups => {
    'infosys' => {
      gid => '996',
    },
  },
  users => {
    'edguser' => {
      'comment' => 'Edguser user',
      'groups'  => [ edguser, infosys, storm, ],
      'uid'     => '995',
      'gid'     => '995',
    },
    'storm' => {
      'comment' => 'StoRM user',
      'groups'  => [ storm, edguser, ],
      'uid'     => '991',
      'gid'     => '991',
    },
  }
}
```

#### Parameters

The following parameters are available in the `storm::users` class:

* [`groups`](#groups)
* [`users`](#users)

##### <a name="groups"></a>`groups`

Data type: `Accounts::Group::Hash`



##### <a name="users"></a>`users`

Data type: `Accounts::User::Hash`



### <a name="stormwebdav"></a>`storm::webdav`

StoRM WebDAV puppet module

#### Examples

##### Basic usage

```puppet

class { 'storm::webdav':
  storage_areas => [
    {
      name                       => 'test.vo',
      root_path                  => '/storage/test.vo',
    },
  ],
}
```

#### Parameters

The following parameters are available in the `storm::webdav` class:

* [`storage_areas`](#storage_areas)
* [`hostnames`](#hostnames)
* [`http_port`](#http_port)
* [`https_port`](#https_port)
* [`trust_anchors_refresh_interval`](#trust_anchors_refresh_interval)
* [`max_concurrent_connections`](#max_concurrent_connections)
* [`max_queue_size`](#max_queue_size)
* [`connector_max_idle_time`](#connector_max_idle_time)
* [`vo_map_files_enable`](#vo_map_files_enable)
* [`vo_map_files_config_dir`](#vo_map_files_config_dir)
* [`vo_map_files_refresh_interval`](#vo_map_files_refresh_interval)
* [`tpc_max_connections`](#tpc_max_connections)
* [`tpc_max_connections_per_route`](#tpc_max_connections_per_route)
* [`tpc_verify_checksum`](#tpc_verify_checksum)
* [`tpc_timeout_in_secs`](#tpc_timeout_in_secs)
* [`tpc_tls_protocol`](#tpc_tls_protocol)
* [`tpc_report_delay_secs`](#tpc_report_delay_secs)
* [`tpc_enable_tls_client_auth`](#tpc_enable_tls_client_auth)
* [`tpc_progress_report_thread_pool_size`](#tpc_progress_report_thread_pool_size)
* [`tpc_enable_expect_continue_threshold`](#tpc_enable_expect_continue_threshold)
* [`jvm_opts`](#jvm_opts)
* [`authz_server_enable`](#authz_server_enable)
* [`authz_server_issuer`](#authz_server_issuer)
* [`authz_server_max_token_lifetime_sec`](#authz_server_max_token_lifetime_sec)
* [`authz_server_secret`](#authz_server_secret)
* [`require_client_cert`](#require_client_cert)
* [`use_conscrypt`](#use_conscrypt)
* [`tpc_use_conscrypt`](#tpc_use_conscrypt)
* [`enable_http2`](#enable_http2)
* [`debug`](#debug)
* [`debug_port`](#debug_port)
* [`debug_suspend`](#debug_suspend)
* [`storm_limit_nofile`](#storm_limit_nofile)
* [`user`](#user)
* [`tape_wellknown_source`](#tape_wellknown_source)
* [`tls_protocol`](#tls_protocol)
* [`checksum_filter_enabled`](#checksum_filter_enabled)
* [`macaroon_filter_enabled`](#macaroon_filter_enabled)
* [`file_buffer_size`](#file_buffer_size)
* [`voms_trust_store_dir`](#voms_trust_store_dir)
* [`voms_trust_store_refresh_interval_sec`](#voms_trust_store_refresh_interval_sec)
* [`voms_cache_enabled`](#voms_cache_enabled)
* [`voms_cache_entry_lifetime_sec`](#voms_cache_entry_lifetime_sec)

##### <a name="storage_areas"></a>`storage_areas`

Data type: `Array[Storm::Webdav::StorageArea]`

List of storage area's configuration. Default value: empty list.

##### <a name="hostnames"></a>`hostnames`

Data type: `Array[String]`

Sets STORM_WEBDAV_HOSTNAME_(N) environment variables.

##### <a name="http_port"></a>`http_port`

Data type: `Integer`

Sets STORM_WEBDAV_HTTP_PORT environment variable.

##### <a name="https_port"></a>`https_port`

Data type: `Integer`

Sets STORM_WEBDAV_HTTPS_PORT environment variable.

##### <a name="trust_anchors_refresh_interval"></a>`trust_anchors_refresh_interval`

Data type: `Integer`

Sets STORM_WEBDAV_TRUST_ANCHORS_REFRESH_INTERVAL environment variable.

##### <a name="max_concurrent_connections"></a>`max_concurrent_connections`

Data type: `Integer`

Sets STORM_WEBDAV_MAX_CONNECTIONS environment variable.

##### <a name="max_queue_size"></a>`max_queue_size`

Data type: `Integer`

Sets STORM_WEBDAV_MAX_QUEUE_SIZE environment variable.

##### <a name="connector_max_idle_time"></a>`connector_max_idle_time`

Data type: `Integer`

Sets STORM_WEBDAV_CONNECTOR_MAX_IDLE_TIME environment variable.

##### <a name="vo_map_files_enable"></a>`vo_map_files_enable`

Data type: `Boolean`

Sets STORM_WEBDAV_VO_MAP_FILES_ENABLE environment variable.

##### <a name="vo_map_files_config_dir"></a>`vo_map_files_config_dir`

Data type: `String`

Sets STORM_WEBDAV_VO_MAP_FILES_CONFIG_DIR environment variable.

##### <a name="vo_map_files_refresh_interval"></a>`vo_map_files_refresh_interval`

Data type: `Integer`

Sets STORM_WEBDAV_VO_MAP_FILES_REFRESH_INTERVAL environment variable.

##### <a name="tpc_max_connections"></a>`tpc_max_connections`

Data type: `Integer`

Sets STORM_WEBDAV_TPC_MAX_CONNECTIONS environment variable.

##### <a name="tpc_max_connections_per_route"></a>`tpc_max_connections_per_route`

Data type: `Integer`

Sets STORM_WEBDAV_TPC_MAX_CONNECTIONS_PER_ROUTE environment variable.

##### <a name="tpc_verify_checksum"></a>`tpc_verify_checksum`

Data type: `Boolean`

Sets STORM_WEBDAV_TPC_VERIFY_CHECKSUM environment variable.

##### <a name="tpc_timeout_in_secs"></a>`tpc_timeout_in_secs`

Data type: `Integer`

Sets STORM_WEBDAV_TPC_TIMEOUT_IN_SECS environment variable.

##### <a name="tpc_tls_protocol"></a>`tpc_tls_protocol`

Data type: `String`

Sets STORM_WEBDAV_TPC_TLS_PROTOCOL environment variable.

##### <a name="tpc_report_delay_secs"></a>`tpc_report_delay_secs`

Data type: `Integer`

Sets STORM_WEBDAV_TPC_REPORT_DELAY_SECS environment variable.

##### <a name="tpc_enable_tls_client_auth"></a>`tpc_enable_tls_client_auth`

Data type: `Boolean`

Sets STORM_WEBDAV_TPC_ENABLE_TLS_CLIENT_AUTH environment variable.

##### <a name="tpc_progress_report_thread_pool_size"></a>`tpc_progress_report_thread_pool_size`

Data type: `Integer`

Sets STORM_WEBDAV_TPC_PROGRESS_REPORT_THREAD_POOL_SIZE environment variable.

##### <a name="tpc_enable_expect_continue_threshold"></a>`tpc_enable_expect_continue_threshold`

Data type: `Integer`

Sets STORM_WEBDAV_TPC_ENABLE_EXPECT_CONTINUE_THRESHOLD environment variable.

##### <a name="jvm_opts"></a>`jvm_opts`

Data type: `String`

Sets part of STORM_WEBDAV_JVM_OPTS environment variable.

##### <a name="authz_server_enable"></a>`authz_server_enable`

Data type: `Boolean`

Sets STORM_WEBDAV_AUTHZ_SERVER_ENABLE environment variable.

##### <a name="authz_server_issuer"></a>`authz_server_issuer`

Data type: `String`

Sets STORM_WEBDAV_AUTHZ_SERVER_ISSUER environment variable if authz_server_enable is true.

##### <a name="authz_server_max_token_lifetime_sec"></a>`authz_server_max_token_lifetime_sec`

Data type: `Integer`

Sets STORM_WEBDAV_AUTHZ_SERVER_MAX_TOKEN_LIFETIME_SEC environment variable if authz_server_enable is true.

##### <a name="authz_server_secret"></a>`authz_server_secret`

Data type: `String`

Sets STORM_WEBDAV_AUTHZ_SERVER_SECRET environment variable if authz_server_enable is true.

##### <a name="require_client_cert"></a>`require_client_cert`

Data type: `Boolean`

Sets STORM_WEBDAV_REQUIRE_CLIENT_CERT environment variable.

##### <a name="use_conscrypt"></a>`use_conscrypt`

Data type: `Boolean`

Sets STORM_WEBDAV_USE_CONSCRYPT environment variable.

##### <a name="tpc_use_conscrypt"></a>`tpc_use_conscrypt`

Data type: `Boolean`

Sets STORM_WEBDAV_TPC_USE_CONSCRYPT environment variable.

##### <a name="enable_http2"></a>`enable_http2`

Data type: `Boolean`

Sets STORM_WEBDAV_ENABLE_HTTP2 environment variable.

##### <a name="debug"></a>`debug`

Data type: `Boolean`

Sets part of STORM_WEBDAV_JVM_OPTS environment variable. It enables remote debug.

##### <a name="debug_port"></a>`debug_port`

Data type: `Integer`

Sets part of STORM_WEBDAV_JVM_OPTS environment variable. It sets the remote debug port if remote debug is enabled.

##### <a name="debug_suspend"></a>`debug_suspend`

Data type: `Boolean`

Sets part of STORM_WEBDAV_JVM_OPTS environment variable. It sets debug suspend value in case remote debug is enabled.

##### <a name="storm_limit_nofile"></a>`storm_limit_nofile`

Data type: `Integer`

Sets LimitNOFILE value.

##### <a name="user"></a>`user`

Data type: `String`

Sets Unix user which runs the service

##### <a name="tape_wellknown_source"></a>`tape_wellknown_source`

Data type: `String`

Sets the absolute path of the source file containing the tape REST API well-known endpoints

##### <a name="tls_protocol"></a>`tls_protocol`

Data type: `String`

Sets TLS protocol for non-TPC requests

##### <a name="checksum_filter_enabled"></a>`checksum_filter_enabled`

Data type: `Boolean`

Enable checksum filter which adds checksum as an header following RFC 3230.

##### <a name="macaroon_filter_enabled"></a>`macaroon_filter_enabled`

Data type: `Boolean`

Enable Macaroon filter to process Macaroon tokens. Requires authz server enabled.

##### <a name="file_buffer_size"></a>`file_buffer_size`

Data type: `Integer`

Buffer size for both internal and third-party copy requests. Valid values are numbers greater/equals than 4096.

##### <a name="voms_trust_store_dir"></a>`voms_trust_store_dir`

Data type: `String`

VOMS Trust Store directory

##### <a name="voms_trust_store_refresh_interval_sec"></a>`voms_trust_store_refresh_interval_sec`

Data type: `Integer`

VOMS Trust Store refresh interval

##### <a name="voms_cache_enabled"></a>`voms_cache_enabled`

Data type: `Boolean`

Enable caching for VOMS certificate validation

##### <a name="voms_cache_entry_lifetime_sec"></a>`voms_cache_entry_lifetime_sec`

Data type: `Integer`

Cache entries lifetime, used if caching for VOMS certificate validation is enabled

### <a name="stormwebdavconfig"></a>`storm::webdav::config`

StoRM WebDAV config class

### <a name="stormwebdavinstall"></a>`storm::webdav::install`

StoRM WebDAV install class

### <a name="stormwebdavservice"></a>`storm::webdav::service`

StoRM WebDAV service class

## Defined types

### <a name="stormbackendservice_conf_file"></a>`storm::backend::service_conf_file`

Starting from Puppet module v2.0.0, site administrators can inject
one or more .conf files into `/etc/systemd/system/storm-backend-server.service.d`
directory.

#### Examples

##### 

```puppet
class { 'storm::backend':
  hostname => 'storm-backend.test.example',
  # ...
}
storm::backend::service_conf_file { 'override.conf':
  source => '/path/to/my/override.conf',
}
```

#### Parameters

The following parameters are available in the `storm::backend::service_conf_file` defined type:

* [`source`](#source)

##### <a name="source"></a>`source`

Data type: `String`

The source of file resource. It can be an absolute path or a Puppet module relative path.

### <a name="stormbackendstorage_site_report"></a>`storm::backend::storage_site_report`

  by using this defined type.

#### Examples

##### 

```puppet
class { 'storm::backend':
  hostname => 'storm-backend.test.example',
  # ...
}
storm::backend::storage_site_report { 'storage-site-report':
  report_path => '/storage/info/report.json', # the internal storage area path
  minute      => '*/20', # set cron's minute
}
```

#### Parameters

The following parameters are available in the `storm::backend::storage_site_report` defined type:

* [`report_path`](#report_path)
* [`minute`](#minute)

##### <a name="report_path"></a>`report_path`

Data type: `String`

The full path of the generated report. Usually it points to a "info" storage area.

##### <a name="minute"></a>`minute`

Data type: `String`

The cron job's minute parameter. Refer to [Resource Type cron](https://puppet.com/docs/puppet/5.5/types/cron.html#cron-attribute-minute).

Default value: `'*/30'`

### <a name="stormrootdir"></a>`storm::rootdir`

StoRM main storage area root directory defined resource

#### Parameters

The following parameters are available in the `storm::rootdir` defined type:

* [`mode`](#mode)

##### <a name="mode"></a>`mode`

Data type: `String`



Default value: `'0755'`

### <a name="stormsarootdir"></a>`storm::sarootdir`

StoRM Storage Area root directory defined resource

#### Parameters

The following parameters are available in the `storm::sarootdir` defined type:

* [`mode`](#mode)

##### <a name="mode"></a>`mode`

Data type: `String`



Default value: `'0750'`

### <a name="stormwebdavapplication_file"></a>`storm::webdav::application_file`

Starting from Puppet module v2.0.0, the management of application.yml
file has been removed from storm::webdav class. Site administrators can edit
their own configuration files or use this defined type to inject one or more YAML
files into the proper directory.

#### Examples

##### 

```puppet
class { 'storm::webdav':
  hostnames => ['storm-webdav.test.example', 'alias-for-storm-webdav.test.example'],
}
storm::webdav::application_file { 'application.yml':
  source => '/path/to/my/application.yml',
}
storm::webdav::application_file { 'application-wlcg.yml':
  source => '/path/to/my/application-wlcg.yml',
}
```

#### Parameters

The following parameters are available in the `storm::webdav::application_file` defined type:

* [`source`](#source)

##### <a name="source"></a>`source`

Data type: `String`

The source of file resource. It can be an absolute path or a Puppet module relative path.

### <a name="stormwebdavdrop_in_file"></a>`storm::webdav::drop_in_file`

Use this define to inject one or more .conf files
into `/etc/systemd/system/storm-webdav.service.d` directory.

#### Examples

##### 

```puppet
class { 'storm::webdav':
  # storm webdav parameters
}
storm::webdav::drop_in_file { 'override.conf':
  source => '/path/to/my/override.conf',
}
```

#### Parameters

The following parameters are available in the `storm::webdav::drop_in_file` defined type:

* [`source`](#source)

##### <a name="source"></a>`source`

Data type: `String`

The source of file resource. It can be an absolute path or a Puppet module relative path.

### <a name="stormwebdavstorage_area_file"></a>`storm::webdav::storage_area_file`

Storage Areas can be configured singularly by using this defined type.
This strategy allows site administrators to keep their manifests unaware of
the improvements on StoRM WebDAV code. For example, if a new property is added
into Storage Area configuration files, you haven't to update your Puppet module
and all the service configuration will continue working.

#### Examples

##### 

```puppet
class { 'storm::webdav':
  hostnames => ['storm-webdav.test.example', 'alias-for-storm-webdav.test.example'],
}
storm::webdav::storage_area_file { 'test.vo.properties':
  source => '/path/to/my/test.vo.properties',
}
storm::webdav::storage_area_file { 'test.vo.2.properties':
  source => '/path/to/my/test.vo.2.properties',
}
```

#### Parameters

The following parameters are available in the `storm::webdav::storage_area_file` defined type:

* [`source`](#source)

##### <a name="source"></a>`source`

Data type: `String`

The source of file resource. It can be an absolute path or a Puppet module relative path.

## Data types

### <a name="stormbackendacl"></a>`Storm::Backend::Acl`

The ACL type for storm-backend-server

Alias of

```puppet
Struct[{
  group => String,
  permission => Enum['R', 'W', 'RW'],
}]
```

### <a name="stormbackendaclmode"></a>`Storm::Backend::AclMode`

The AclMode type for storm-backend-server

Alias of

```puppet
Enum['AoT', 'JiT']
```

### <a name="stormbackendbalancestrategy"></a>`Storm::Backend::BalanceStrategy`

The BalanceStrategy type for storm-backend-server

Alias of

```puppet
Enum['round-robin', 'smart-rr', 'random', 'weight']
```

### <a name="stormbackendendpoint"></a>`Storm::Backend::Endpoint`

The Endpoint type for storm-backend-server

Alias of

```puppet
Struct[{
  schema   => Enum['rfio','xroot','gsiftp','srm','http','https'],
  hostname => String,
  port     => Integer,
  path     => String,
}]
```

### <a name="stormbackendfilesystem"></a>`Storm::Backend::FileSystem`

The FileSystem type for storm-backend-server

Alias of

```puppet
Struct[{
  type => Enum['ext3', 'gpfs'],
  driver => Enum['posixfs', 'gpfs', 'test'],
  space_system => Optional[Enum['MockSpaceSystem', 'GPFSSpaceSystem']],
}]
```

### <a name="stormbackendfsdriver"></a>`Storm::Backend::FsDriver`

The FsDriver type for storm-backend-server

Alias of

```puppet
Enum['posixfs', 'gpfs', 'test']
```

### <a name="stormbackendfstype"></a>`Storm::Backend::FsType`

The FsType type for storm-backend-server

Alias of

```puppet
Enum['posixfs', 'gpfs', 'test']
```

### <a name="stormbackendgsiftp"></a>`Storm::Backend::Gsiftp`

The Gsiftp type for storm-backend-server

Alias of

```puppet
Struct[{
  pool => Storm::Backend::Pool,
}]
```

### <a name="stormbackendgsiftppoolmember"></a>`Storm::Backend::GsiftpPoolMember`

The GsiftpPoolMember type for storm-backend-server

Alias of

```puppet
Struct[{
  hostname => String,
  port     => Optional[Integer],
  weight   => Optional[Integer],
}]
```

### <a name="stormbackendpool"></a>`Storm::Backend::Pool`

The Pool type for storm-backend-server

Alias of

```puppet
Struct[{
  balance_strategy => Optional[Enum['round-robin', 'smart-rr', 'random', 'weight']],
  members          => Array[Struct[{
    hostname => String,
    port     => Optional[Integer],
    weigth   => Optional[Integer],
  }]],
}]
```

### <a name="stormbackendquota"></a>`Storm::Backend::Quota`

The Quota type for storm-backend-server

Alias of

```puppet
Struct[{
  device => String,
  type   => Enum['username', 'group', 'fileset'],
  value  => String,
}]
```

### <a name="stormbackendrfio"></a>`Storm::Backend::Rfio`

The Rfio type for storm-backend-server

Alias of

```puppet
Struct[{
  hostname => String,
  port => Optional[Integer],
}]
```

### <a name="stormbackendsrmpoolmember"></a>`Storm::Backend::SrmPoolMember`

The SrmPoolMember type for storm-backend-server

Alias of

```puppet
Struct[{
  hostname => String,
  port     => Optional[Integer],
}]
```

### <a name="stormbackendstoragearea"></a>`Storm::Backend::StorageArea`

The storage area type for storm-backend-server

Alias of

```puppet
Struct[{
    name                         => String,
    root_path                    => String,
    access_points                => Array[String],
    vos                          => Array[String],
    fs_type                      => Optional[Storm::Backend::FsType],
    space_token                  => Optional[String],
    authz                        => Optional[String],
    storage_class                => Optional[Storm::Backend::StorageClass],
    online_size                  => Integer,
    nearline_size                => Optional[Integer],
    acl_mode                     => Optional[Storm::Backend::AclMode],
    default_acl_list             => Optional[Array[Storm::Backend::Acl]],
    quota                        => Optional[Storm::Backend::Quota],
    dn_regex                     => Optional[String],
    anonymous_http_read          => Optional[Boolean],
    transfer_protocols           => Optional[Array[Storm::Backend::TransferProtocol]],
    rfio_hostname                => Optional[String],
    rfio_port                    => Optional[Integer],
    xroot_hostname               => Optional[String],
    xroot_port                   => Optional[Integer],
    gsiftp_pool_balance_strategy => Optional[Storm::Backend::BalanceStrategy],
    gsiftp_pool_members          => Optional[Array[Storm::Backend::GsiftpPoolMember]],
    webdav_pool_balance_strategy => Optional[Storm::Backend::BalanceStrategy],
    webdav_pool_members          => Optional[Array[Storm::Backend::WebdavPoolMember]],
}]
```

### <a name="stormbackendstorageclass"></a>`Storm::Backend::StorageClass`

The StorageClass type for storm-backend-server

Alias of

```puppet
Enum['T0D1', 'T1D0', 'T1D1']
```

### <a name="stormbackendtransferprotocol"></a>`Storm::Backend::TransferProtocol`

The TransferProtocol type for storm-backend-server

Alias of

```puppet
Enum['file', 'gsiftp', 'xroot', 'webdav']
```

### <a name="stormbackendwebdav"></a>`Storm::Backend::Webdav`

The WebDAV type for storm-backend-server

Alias of

```puppet
Struct[{
  pool => Array[Struct[{
    hostname => String,
    port     => Optional[Integer],
  }]],
}]
```

### <a name="stormbackendwebdavpoolmember"></a>`Storm::Backend::WebdavPoolMember`

The WebdavPoolMember type for storm-backend-server

Alias of

```puppet
Struct[{
  hostname => String,
  http_port => Optional[Integer],
  https_port => Optional[Integer],
}]
```

### <a name="stormbackendxroot"></a>`Storm::Backend::Xroot`

The Xroot type for storm-backend-server

Alias of

```puppet
Struct[{
  hostname => String,
  port => Optional[Integer],
}]
```

### <a name="stormcustomrepo"></a>`Storm::CustomRepo`

The storage area type for storm-webdav

Alias of

```puppet
Struct[{
  name    => String,
  baseurl => String,
}]
```

### <a name="stormwebdavstoragearea"></a>`Storm::Webdav::StorageArea`

The storage area type for storm-webdav.

Alias of

```puppet
Struct[{
  name                           => String,
  root_path                      => String,
  filesystem_type                => Optional[String],
  access_points                  => Optional[Array[String]],
  vos                            => Optional[Array[String]],
  orgs                           => Optional[Array[String]],
  authenticated_read_enabled     => Optional[Boolean],
  anonymous_read_enabled         => Optional[Boolean],
  vo_map_enabled                 => Optional[Boolean],
  vo_map_grants_write_permission => Optional[Boolean],
  orgs_grant_read_permission     => Optional[Boolean],
  orgs_grant_write_permission    => Optional[Boolean],
  wlcg_scope_authz_enabled       => Optional[Boolean],
  fine_grained_authz_enabled     => Optional[Boolean],
}]
```

